@@ -9,10 +9,10 @@ gist_list <- function(username){
   if(grepl("darwin", R.Version()$platform)){
     out <-  eval_psock(httr::GET(myurl, httr::add_headers("User-Agent" = "OpenCPU")), list(myurl=myurl));
   } else {
-    out <- GET(myurl, add_headers("User-Agent" = "OpenCPU"));
+    out <- httr::GET(myurl, httr::add_headers("User-Agent" = "OpenCPU"));
   }  
 
-  stop_for_status(out);
+  httr::stop_for_status(out);
   response <- fromJSON(rawToChar(out$content));
   
   #proxy limit headers
